@@ -17,7 +17,11 @@ class ProspectSequenceStepEvent:
     created_at: str
     sequence_step: SequenceStep
     type: ProspectSequenceStepEventType
+    # According to "Managing Threads" from the GMail API (https://developers.google.com/gmail/api/guides/threads):
+    # - The request threadId bust be specified on the Message (thread_id)
+    # - The headers "In-Reply-To" and "References" must be set in compliance with RFC2922 (message_id)
     thread_id: Optional[str] = None
+    message_id: Optional[str] = None
 
 
 @dataclass_json
